# Optimization

Optimization commands are used to perform topology, shape, or sizing optimization of your model given a set of objectives and a set of restrictions.

## Create optimization tasks

```{eval-rst}
.. autoclass:: abaqus.Optimization.OptimizationTaskModel.OptimizationTaskModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Assign features to optimization tasks

```{eval-rst}
.. autoclass:: abaqus.Optimization.OptimizationTask.OptimizationTask
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Optimization
        :recursive:
        :exclude: OptimizationTaskModel, OptimizationTask
```
